View source: R/format_databases.R
| format_database | R Documentation |
General functions to format user-specified databases
format_database(
data_tables,
data_path,
output_directory_path,
temp_directory_path,
metabarcode,
db_its,
db_rps10,
db_16S,
db_other1,
db_other2
)
data_tables |
The data tables containing the paths to read files, metadata, and metabarcode information with associated primer sequences |
data_path |
Path to the data directory |
output_directory_path |
The path to the directory where resulting files are output |
temp_directory_path |
User-defined temporary directory to output unfiltered, trimmed, and filtered read directories throughout the workflow |
metabarcode |
The metabarcode used throughout the workflow (applicable options: 'rps10', 'its', 'r16S', 'other1', other2') |
Formatted database(s) for the specified metabarcode type(s)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.